@@ -7,7 +7,7 @@
 
 #include "compositor.h"
 #include "display.h"
-#include "mutter-plugin-manager.h"
+#include "meta-plugin-manager.h"
 #include <clutter/clutter.h>
 
 typedef struct _MetaCompScreen MetaCompScreen;
@@ -23,6 +23,8 @@ struct _MetaCompositor
 
   ClutterActor   *shadow_src;
 
+  MetaPlugin     *modal_plugin;
+
   gboolean        show_redraw : 1;
   gboolean        debug       : 1;
   gboolean        no_mipmaps  : 1;
@@ -43,12 +45,24 @@ struct _MetaCompScreen
 
   gint                   switch_workspace_in_progress;
 
-  MutterPluginManager *plugin_mgr;
+  MetaPluginManager *plugin_mgr;
 };
 
-void mutter_switch_workspace_completed (MetaScreen    *screen);
-void mutter_set_stage_input_region     (MetaScreen    *screen,
-                                        XserverRegion  region);
-void mutter_empty_stage_input_region   (MetaScreen    *screen);
+void meta_switch_workspace_completed (MetaScreen    *screen);
+void meta_set_stage_input_region     (MetaScreen    *screen,
+                                      XserverRegion  region);
+void meta_empty_stage_input_region   (MetaScreen    *screen);
+
+gboolean meta_begin_modal_for_plugin (MetaScreen       *screen,
+                                      MetaPlugin       *plugin,
+                                      Window            grab_window,
+                                      Cursor            cursor,
+                                      MetaModalOptions  options,
+                                      guint32           timestamp);
+void     meta_end_modal_for_plugin   (MetaScreen       *screen,
+                                      MetaPlugin       *plugin,
+                                      guint32           timestamp);
+
+void meta_check_end_modal (MetaScreen *screen);
 
 #endif /* META_COMPOSITOR_PRIVATE_H */
