@@ -11,8 +11,8 @@
 #include "compositor-mutter.h"
 #include "xprops.h"
 #include "prefs.h"
-#include "mutter-window-private.h"
-#include "mutter-window-group.h"
+#include "meta-window-actor-private.h"
+#include "meta-window-group.h"
 #include "../core/window-private.h" /* to check window->hidden */
 #include "../core/display-private.h" /* for meta_display_lookup_x_window() */
 #include <X11/extensions/shape.h>
@@ -33,69 +33,16 @@ composite_at_least_version (MetaDisplay *display, int maj, int min)
   return (major > maj || (major == maj && minor >= min));
 }
 
-static MutterWindow*
-find_window_for_screen (MetaScreen *screen, Window xwindow)
-{
-  MetaCompScreen *info = meta_screen_get_compositor_data (screen);
-
-  if (info == NULL)
-    return NULL;
-
-  return g_hash_table_lookup (info->windows_by_xid,
-                              (gpointer) xwindow);
-}
-
-static MutterWindow *
-find_window_in_display (MetaDisplay *display, Window xwindow)
-{
-  GSList *index;
-  MetaWindow *window = meta_display_lookup_x_window (display, xwindow);
-
-  if (window)
-    {
-      void *priv = meta_window_get_compositor_private (window);
-      if (priv)
-	return priv;
-    }
-
-  for (index = meta_display_get_screens (display);
-       index;
-       index = index->next)
-    {
-      MutterWindow *cw = find_window_for_screen (index->data, xwindow);
-
-      if (cw != NULL)
-        return cw;
-    }
-
-  return NULL;
-}
-
-static MutterWindow *
-find_window_for_child_window_in_display (MetaDisplay *display, Window xwindow)
-{
-  Window ignored1, *ignored2, parent;
-  guint  ignored_children;
-
-  XQueryTree (meta_display_get_xdisplay (display), xwindow, &ignored1,
-              &parent, &ignored2, &ignored_children);
-
-  if (parent != None)
-    return find_window_in_display (display, parent);
-
-  return NULL;
-}
-
 static void sync_actor_stacking (GList *windows);
 
 static void
-mutter_finish_workspace_switch (MetaCompScreen *info)
+meta_finish_workspace_switch (MetaCompScreen *info)
 {
   GList *l;
 
   /* Finish hiding and showing actors for the new workspace */
   for (l = info->windows; l; l = l->next)
-    mutter_window_sync_visibility (l->data);
+    meta_window_actor_sync_visibility (l->data);
 
   /*
    * Fix up stacking order in case the plugin messed it up.
@@ -107,7 +54,7 @@ mutter_finish_workspace_switch (MetaCompScreen *info)
 }
 
 void
-mutter_switch_workspace_completed (MetaScreen *screen)
+meta_switch_workspace_completed (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
 
@@ -120,7 +67,7 @@ mutter_switch_workspace_completed (MetaScreen *screen)
     }
 
   if (!info->switch_workspace_in_progress)
-    mutter_finish_workspace_switch (info);
+    meta_finish_workspace_switch (info);
 }
 
 void
@@ -137,82 +84,72 @@ add_win (MetaWindow *window)
 
   g_return_if_fail (info != NULL);
 
-  mutter_window_new (window);
+  meta_window_actor_new (window);
 
   sync_actor_stacking (info->windows);
 }
 
 static void
 process_damage (MetaCompositor     *compositor,
-                XDamageNotifyEvent *event)
+                XDamageNotifyEvent *event,
+                MetaWindow         *window)
 {
-  MutterWindow *cw = find_window_in_display (compositor->display, event->drawable);
-  if (cw == NULL)
+  MetaWindowActor *window_actor;
+
+  if (window == NULL)
     return;
 
-  mutter_window_process_damage (cw, event);
+  window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
+  if (window_actor == NULL)
+    return;
+
+  meta_window_actor_process_damage (window_actor, event);
 }
 
 #ifdef HAVE_SHAPE
 static void
 process_shape (MetaCompositor *compositor,
-               XShapeEvent    *event)
+               XShapeEvent    *event,
+               MetaWindow     *window)
 {
-  MutterWindow *cw = find_window_in_display (compositor->display,
-                                             event->window);
-  if (cw == NULL)
+  MetaWindowActor *window_actor;
+
+  if (window == NULL)
+    return;
+
+  window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
+  if (window_actor == NULL)
     return;
 
   if (event->kind == ShapeBounding)
     {
-      mutter_window_update_shape (cw, event->shaped);
+      meta_window_actor_update_shape (window_actor, event->shaped);
     }
 }
 #endif
 
 static void
 process_property_notify (MetaCompositor	*compositor,
-                         XPropertyEvent *event)
+                         XPropertyEvent *event,
+                         MetaWindow     *window)
 {
-  MetaDisplay *display = compositor->display;
+  MetaWindowActor *window_actor;
+
+  if (window == NULL)
+    return;
+
+  window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
+  if (window_actor == NULL)
+    return;
 
   /* Check for the opacity changing */
   if (event->atom == compositor->atom_net_wm_window_opacity)
     {
-      MutterWindow *cw = find_window_in_display (display, event->window);
-
-      if (!cw)
-        {
-          /* Applications can set this for their toplevel windows, so
-           * this must be propagated to the window managed by the compositor
-           */
-          cw = find_window_for_child_window_in_display (display,
-                                                        event->window);
-        }
-
-      if (!cw)
-	{
-	  DEBUG_TRACE ("process_property_notify: opacity, early exit\n");
-	  return;
-	}
-
-      mutter_window_update_opacity (cw);
-    }
-  else if (event->atom == meta_display_get_atom (display,
-					       META_ATOM__NET_WM_WINDOW_TYPE))
-    {
-      MutterWindow *cw = find_window_in_display (display, event->window);
-
-      if (!cw)
-	{
-	  DEBUG_TRACE ("process_property_notify: net_wm_type, early exit\n");
-	  return;
-	}
-
-      mutter_window_update_window_type (cw);
-      DEBUG_TRACE ("process_property_notify: net_wm_type\n");
+      meta_window_actor_update_opacity (window_actor);
+      DEBUG_TRACE ("process_property_notify: net_wm_window_opacity\n");
       return;
     }
+
   DEBUG_TRACE ("process_property_notify: unknown\n");
 }
 
@@ -247,8 +184,14 @@ get_output_window (MetaScreen *screen)
   return output;
 }
 
+/**
+ * meta_get_stage_for_screen:
+ * @screen: a #MetaScreen
+ *
+ * Returns: (transfer none): The #ClutterStage for the screen
+ */
 ClutterActor *
-mutter_get_stage_for_screen (MetaScreen *screen)
+meta_get_stage_for_screen (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
 
@@ -258,8 +201,14 @@ mutter_get_stage_for_screen (MetaScreen *screen)
   return info->stage;
 }
 
+/**
+ * meta_get_overlay_group_for_screen:
+ * @screen: a #MetaScreen
+ *
+ * Returns: (transfer none): The overlay group corresponding to @screen
+ */
 ClutterActor *
-mutter_get_overlay_group_for_screen (MetaScreen *screen)
+meta_get_overlay_group_for_screen (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
 
@@ -269,8 +218,14 @@ mutter_get_overlay_group_for_screen (MetaScreen *screen)
   return info->overlay_group;
 }
 
+/**
+ * meta_get_window_group_for_screen:
+ * @screen: a #MetaScreen
+ *
+ * Returns: (transfer none): The window group corresponding to @screen
+ */
 ClutterActor *
-mutter_get_window_group_for_screen (MetaScreen *screen)
+meta_get_window_group_for_screen (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
 
@@ -280,8 +235,14 @@ mutter_get_window_group_for_screen (MetaScreen *screen)
   return info->window_group;
 }
 
+/**
+ * meta_get_window_actors:
+ * @screen: a #MetaScreen
+ *
+ * Returns: (transfer none) (element-type Clutter.Actor): The set of #MetaWindowActor on @screen
+ */
 GList *
-mutter_get_windows (MetaScreen *screen)
+meta_get_window_actors (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
 
@@ -292,7 +253,7 @@ mutter_get_windows (MetaScreen *screen)
 }
 
 static void
-do_set_stage_input_region (MetaScreen *screen,
+do_set_stage_input_region (MetaScreen   *screen,
                            XserverRegion region)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
@@ -305,8 +266,8 @@ do_set_stage_input_region (MetaScreen *screen,
 }
 
 void
-mutter_set_stage_input_region (MetaScreen *screen,
-                               XserverRegion region)
+meta_set_stage_input_region (MetaScreen   *screen,
+                             XserverRegion region)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
   MetaDisplay  *display = meta_screen_get_display (screen);
@@ -334,7 +295,7 @@ mutter_set_stage_input_region (MetaScreen *screen,
 }
 
 void
-mutter_empty_stage_input_region (MetaScreen *screen)
+meta_empty_stage_input_region (MetaScreen *screen)
 {
   /* Using a static region here is a bit hacky, but Metacity never opens more than
    * one XDisplay, so it works fine. */
@@ -347,16 +308,16 @@ mutter_empty_stage_input_region (MetaScreen *screen)
       region = XFixesCreateRegion (xdpy, NULL, 0);
     }
 
-  mutter_set_stage_input_region (screen, region);
+  meta_set_stage_input_region (screen, region);
 }
 
 gboolean
-mutter_begin_modal_for_plugin (MetaScreen       *screen,
-                               MutterPlugin     *plugin,
-                               Window            grab_window,
-                               Cursor            cursor,
-                               MetaModalOptions  options,
-                               guint32           timestamp)
+meta_begin_modal_for_plugin (MetaScreen       *screen,
+                             MetaPlugin       *plugin,
+                             Window            grab_window,
+                             Cursor            cursor,
+                             MetaModalOptions  options,
+                             guint32           timestamp)
 {
   /* To some extent this duplicates code in meta_display_begin_grab_op(), but there
    * are significant differences in how we handle grabs that make it difficult to
@@ -390,10 +351,10 @@ mutter_begin_modal_for_plugin (MetaScreen       *screen,
 
   if ((options & META_MODAL_KEYBOARD_ALREADY_GRABBED) == 0)
     {
-      XGrabKeyboard (xdpy, grab_window,
-                     False, /* owner_events */
-                     GrabModeAsync, GrabModeAsync,
-                     timestamp);
+      result = XGrabKeyboard (xdpy, grab_window,
+                              False, /* owner_events */
+                              GrabModeAsync, GrabModeAsync,
+                              timestamp);
 
       if (result != Success)
         goto fail;
@@ -421,9 +382,9 @@ mutter_begin_modal_for_plugin (MetaScreen       *screen,
 }
 
 void
-mutter_end_modal_for_plugin (MetaScreen       *screen,
-                             MutterPlugin     *plugin,
-                             guint32           timestamp)
+meta_end_modal_for_plugin (MetaScreen     *screen,
+                           MetaPlugin     *plugin,
+                           guint32         timestamp)
 {
   MetaDisplay    *display    = meta_screen_get_display (screen);
   Display        *xdpy = meta_display_get_xdisplay (display);
@@ -447,15 +408,15 @@ mutter_end_modal_for_plugin (MetaScreen       *screen,
  * a left-over modal grab for this screen.
  */
 void
-mutter_check_end_modal (MetaScreen *screen)
+meta_check_end_modal (MetaScreen *screen)
 {
   MetaDisplay    *display    = meta_screen_get_display (screen);
   MetaCompositor *compositor = display->compositor;
 
   if (compositor->modal_plugin &&
-      mutter_plugin_get_screen (compositor->modal_plugin) == screen)
+      meta_plugin_get_screen (compositor->modal_plugin) == screen)
     {
-      mutter_end_modal_for_plugin (screen,
+      meta_end_modal_for_plugin (screen,
                                    compositor->modal_plugin,
                                    CurrentTime);
     }
@@ -505,7 +466,6 @@ meta_compositor_manage_screen (MetaCompositor *compositor,
 
   info->output = None;
   info->windows = NULL;
-  info->windows_by_xid = g_hash_table_new (g_direct_hash, g_direct_equal);
 
   meta_screen_set_cm_selection (screen);
 
@@ -532,7 +492,7 @@ meta_compositor_manage_screen (MetaCompositor *compositor,
 
   XSelectInput (xdisplay, xwin, event_mask);
 
-  info->window_group = mutter_window_group_new (screen);
+  info->window_group = meta_window_group_new (screen);
   info->overlay_group = clutter_group_new ();
   info->hidden_group = clutter_group_new ();
 
@@ -545,10 +505,18 @@ meta_compositor_manage_screen (MetaCompositor *compositor,
   clutter_actor_hide (info->hidden_group);
 
   info->plugin_mgr =
-    mutter_plugin_manager_new (screen);
-  if (!mutter_plugin_manager_load (info->plugin_mgr))
-    g_critical ("failed to load plugins");
-  if (!mutter_plugin_manager_initialize (info->plugin_mgr))
+    meta_plugin_manager_get (screen);
+
+  if (info->plugin_mgr != meta_plugin_manager_get_default ())
+    {
+      /* The default plugin manager has been initialized during
+       * global preferences load.
+       */
+      if (!meta_plugin_manager_load (info->plugin_mgr))
+        g_critical ("failed to load plugins");
+    }
+
+  if (!meta_plugin_manager_initialize (info->plugin_mgr))
     g_critical ("failed to initialize plugins");
 
   /*
@@ -607,14 +575,14 @@ void
 meta_compositor_remove_window (MetaCompositor *compositor,
                                MetaWindow     *window)
 {
-  MutterWindow         *cw     = NULL;
+  MetaWindowActor         *window_actor     = NULL;
 
   DEBUG_TRACE ("meta_compositor_remove_window\n");
-  cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
-  if (!cw)
+  window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
+  if (!window_actor)
     return;
 
-  mutter_window_destroy (cw);
+  meta_window_actor_destroy (window_actor);
 }
 
 void
@@ -634,14 +602,17 @@ is_grabbed_event (XEvent *event)
     case EnterNotify:
     case LeaveNotify:
     case MotionNotify:
-    case KeyPressMask:
-    case KeyReleaseMask:
+    case KeyPress:
+    case KeyRelease:
       return TRUE;
     }
 
   return FALSE;
 }
-
+/**
+ * meta_compositor_process_event: (skip)
+ *
+ */
 gboolean
 meta_compositor_process_event (MetaCompositor *compositor,
                                XEvent         *event,
@@ -649,7 +620,7 @@ meta_compositor_process_event (MetaCompositor *compositor,
 {
   if (compositor->modal_plugin && is_grabbed_event (event))
     {
-      MutterPluginClass *klass = MUTTER_PLUGIN_GET_CLASS (compositor->modal_plugin);
+      MetaPluginClass *klass = META_PLUGIN_GET_CLASS (compositor->modal_plugin);
 
       if (klass->xevent_filter)
         klass->xevent_filter (compositor->modal_plugin, event);
@@ -667,7 +638,7 @@ meta_compositor_process_event (MetaCompositor *compositor,
       screen = meta_window_get_screen (window);
       info = meta_screen_get_compositor_data (screen);
 
-      if (mutter_plugin_manager_xevent_filter (info->plugin_mgr, event))
+      if (meta_plugin_manager_xevent_filter (info->plugin_mgr, event))
 	{
 	  DEBUG_TRACE ("meta_compositor_process_event (filtered,window==NULL)\n");
 	  return TRUE;
@@ -686,7 +657,7 @@ meta_compositor_process_event (MetaCompositor *compositor,
 
 	  info = meta_screen_get_compositor_data (screen);
 
-	  if (mutter_plugin_manager_xevent_filter (info->plugin_mgr, event))
+	  if (meta_plugin_manager_xevent_filter (info->plugin_mgr, event))
 	    {
 	      DEBUG_TRACE ("meta_compositor_process_event (filtered,window==NULL)\n");
 	      return TRUE;
@@ -696,38 +667,37 @@ meta_compositor_process_event (MetaCompositor *compositor,
 	}
     }
 
-  /*
-   * This trap is so that none of the compositor functions cause
-   * X errors. This is really a hack, but I'm afraid I don't understand
-   * enough about Metacity/X to know how else you are supposed to do it
-   */
-
-
-  meta_error_trap_push (compositor->display);
   switch (event->type)
     {
     case PropertyNotify:
-      process_property_notify (compositor, (XPropertyEvent *) event);
+      process_property_notify (compositor, (XPropertyEvent *) event, window);
       break;
 
     default:
       if (event->type == meta_display_get_damage_event_base (compositor->display) + XDamageNotify)
         {
+          /* Core code doesn't handle damage events, so we need to extract the MetaWindow
+           * ourselves
+           */
+          if (window == NULL)
+            {
+              Window xwin = ((XDamageNotifyEvent *) event)->drawable;
+              window = meta_display_lookup_x_window (compositor->display, xwin);
+            }
+
 	  DEBUG_TRACE ("meta_compositor_process_event (process_damage)\n");
-          process_damage (compositor, (XDamageNotifyEvent *) event);
+          process_damage (compositor, (XDamageNotifyEvent *) event, window);
         }
 #ifdef HAVE_SHAPE
       else if (event->type == meta_display_get_shape_event_base (compositor->display) + ShapeNotify)
 	{
 	  DEBUG_TRACE ("meta_compositor_process_event (process_shape)\n");
-	  process_shape (compositor, (XShapeEvent *) event);
+	  process_shape (compositor, (XShapeEvent *) event, window);
 	}
 #endif /* HAVE_SHAPE */
       break;
     }
 
-  meta_error_trap_pop (compositor->display, FALSE);
-
   /* Clutter needs to know about MapNotify events otherwise it will
      think the stage is invisible */
   if (event->type == MapNotify)
@@ -745,12 +715,12 @@ meta_compositor_show_window (MetaCompositor *compositor,
 			     MetaWindow	    *window,
                              MetaCompEffect  effect)
 {
-  MutterWindow *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
   DEBUG_TRACE ("meta_compositor_show_window\n");
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_show (cw, effect);
+  meta_window_actor_show (window_actor, effect);
 }
 
 void
@@ -758,12 +728,12 @@ meta_compositor_hide_window (MetaCompositor *compositor,
                              MetaWindow     *window,
                              MetaCompEffect  effect)
 {
-  MutterWindow *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
   DEBUG_TRACE ("meta_compositor_hide_window\n");
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_hide (cw, effect);
+  meta_window_actor_hide (window_actor, effect);
 }
 
 void
@@ -772,12 +742,12 @@ meta_compositor_maximize_window (MetaCompositor    *compositor,
 				 MetaRectangle	   *old_rect,
 				 MetaRectangle	   *new_rect)
 {
-  MutterWindow	 *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
   DEBUG_TRACE ("meta_compositor_maximize_window\n");
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_maximize (cw, old_rect, new_rect);
+  meta_window_actor_maximize (window_actor, old_rect, new_rect);
 }
 
 void
@@ -786,12 +756,12 @@ meta_compositor_unmaximize_window (MetaCompositor    *compositor,
 				   MetaRectangle     *old_rect,
 				   MetaRectangle     *new_rect)
 {
-  MutterWindow	 *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
   DEBUG_TRACE ("meta_compositor_unmaximize_window\n");
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_unmaximize (cw, old_rect, new_rect);
+  meta_window_actor_unmaximize (window_actor, old_rect, new_rect);
 }
 
 void
@@ -804,7 +774,7 @@ meta_compositor_update_workspace_geometry (MetaCompositor *compositor,
    */
   MetaScreen     *screen = meta_workspace_get_screen (workspace);
   MetaCompScreen *info;
-  MutterPluginManager *mgr;
+  MetaPluginManager *mgr;
 
   DEBUG_TRACE ("meta_compositor_update_workspace_geometry\n");
   info = meta_screen_get_compositor_data (screen);
@@ -813,7 +783,7 @@ meta_compositor_update_workspace_geometry (MetaCompositor *compositor,
   if (!mgr || !workspace)
     return;
 
-  mutter_plugin_manager_update_workspace (mgr, workspace);
+  meta_plugin_manager_update_workspace (mgr, workspace);
 #endif
 }
 
@@ -839,8 +809,7 @@ meta_compositor_switch_workspace (MetaCompositor     *compositor,
   info->switch_workspace_in_progress++;
 
   if (!info->plugin_mgr ||
-      !mutter_plugin_manager_switch_workspace (info->plugin_mgr,
-					       (const GList **)&info->windows,
+      !meta_plugin_manager_switch_workspace (info->plugin_mgr,
 					       from_indx,
 					       to_indx,
 					       direction))
@@ -852,7 +821,7 @@ meta_compositor_switch_workspace (MetaCompositor     *compositor,
        * necessarily change during the window hiding/unhiding, only their
        * relative position toward the destkop window.
        */
-      mutter_finish_workspace_switch (info);
+      meta_finish_workspace_switch (info);
     }
 }
 
@@ -865,9 +834,9 @@ sync_actor_stacking (GList *windows)
 
   for (tmp = g_list_last (windows); tmp != NULL; tmp = tmp->prev)
     {
-      MutterWindow *cw = tmp->data;
+      MetaWindowActor *window_actor = tmp->data;
 
-      clutter_actor_lower_bottom (CLUTTER_ACTOR (cw));
+      clutter_actor_lower_bottom (CLUTTER_ACTOR (window_actor));
     }
 }
 
@@ -889,12 +858,12 @@ meta_compositor_sync_stack (MetaCompositor  *compositor,
 
   /* Sources: first window is the highest */
   stack = g_list_copy (stack); /* The new stack of MetaWindow */
-  old_stack = g_list_reverse (info->windows); /* The old stack of MutterWindow */
+  old_stack = g_list_reverse (info->windows); /* The old stack of MetaWindowActor */
   info->windows = NULL;
 
   while (TRUE)
     {
-      MutterWindow *old_actor = NULL, *stack_actor = NULL, *actor;
+      MetaWindowActor *old_actor = NULL, *stack_actor = NULL, *actor;
       MetaWindow *old_window = NULL, *stack_window = NULL, *window;
 
       /* Find the remaining top actor in our existing stack (ignoring
@@ -902,10 +871,10 @@ meta_compositor_sync_stack (MetaCompositor  *compositor,
       while (old_stack)
         {
           old_actor = old_stack->data;
-          old_window = mutter_window_get_meta_window (old_actor);
+          old_window = meta_window_actor_get_meta_window (old_actor);
 
           if (old_window->hidden &&
-              !mutter_window_effect_in_progress (old_actor))
+              !meta_window_actor_effect_in_progress (old_actor))
             old_stack = g_list_delete_link (old_stack, old_stack);
           else
             break;
@@ -915,10 +884,10 @@ meta_compositor_sync_stack (MetaCompositor  *compositor,
       while (stack)
         {
           stack_window = stack->data;
-          stack_actor = MUTTER_WINDOW (meta_window_get_compositor_private (stack_window));
+          stack_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (stack_window));
           if (!stack_actor)
             {
-              meta_verbose ("Failed to find corresponding MutterWindow "
+              meta_verbose ("Failed to find corresponding MetaWindowActor "
                             "for window %s\n", meta_window_get_description (stack_window));
               stack = g_list_delete_link (stack, stack);
             }
@@ -964,41 +933,41 @@ void
 meta_compositor_window_mapped (MetaCompositor *compositor,
                                MetaWindow     *window)
 {
-  MutterWindow *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
   DEBUG_TRACE ("meta_compositor_window_mapped\n");
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_mapped (cw);
+  meta_window_actor_mapped (window_actor);
 }
 
 void
 meta_compositor_window_unmapped (MetaCompositor *compositor,
                                  MetaWindow     *window)
 {
-  MutterWindow *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
   DEBUG_TRACE ("meta_compositor_window_unmapped\n");
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_unmapped (cw);
+  meta_window_actor_unmapped (window_actor);
 }
 
 void
 meta_compositor_sync_window_geometry (MetaCompositor *compositor,
 				      MetaWindow *window)
 {
-  MutterWindow	 *cw = MUTTER_WINDOW (meta_window_get_compositor_private (window));
-  MetaScreen	 *screen = meta_window_get_screen (window);
-  MetaCompScreen *info = meta_screen_get_compositor_data (screen);
+  MetaWindowActor *window_actor = META_WINDOW_ACTOR (meta_window_get_compositor_private (window));
+  MetaScreen      *screen = meta_window_get_screen (window);
+  MetaCompScreen  *info = meta_screen_get_compositor_data (screen);
 
   DEBUG_TRACE ("meta_compositor_sync_window_geometry\n");
   g_return_if_fail (info);
 
-  if (!cw)
+  if (!window_actor)
     return;
 
-  mutter_window_sync_actor_position (cw);
+  meta_window_actor_sync_actor_position (window_actor);
 }
 
 void
@@ -1025,11 +994,11 @@ pre_paint_windows (MetaCompScreen *info)
   GList *l;
 
   for (l = info->windows; l; l = l->next)
-    mutter_window_pre_paint (l->data);
+    meta_window_actor_pre_paint (l->data);
 }
 
 static gboolean
-mutter_repaint_func (gpointer data)
+meta_repaint_func (gpointer data)
 {
   MetaCompositor *compositor = data;
   GSList *screens = meta_display_get_screens (compositor->display);
@@ -1048,6 +1017,10 @@ mutter_repaint_func (gpointer data)
   return TRUE;
 }
 
+/**
+ * meta_compositor_new: (skip)
+ *
+ */
 MetaCompositor *
 meta_compositor_new (MetaDisplay *display)
 {
@@ -1067,7 +1040,7 @@ meta_compositor_new (MetaDisplay *display)
 
   compositor->display = display;
 
-  if (g_getenv("MUTTER_DISABLE_MIPMAPS"))
+  if (g_getenv("META_DISABLE_MIPMAPS"))
     compositor->no_mipmaps = TRUE;
 
   meta_verbose ("Creating %d atoms\n", (int) G_N_ELEMENTS (atom_names));
@@ -1078,15 +1051,19 @@ meta_compositor_new (MetaDisplay *display)
   compositor->atom_x_set_root = atoms[1];
   compositor->atom_net_wm_window_opacity = atoms[2];
 
-  compositor->repaint_func_id = clutter_threads_add_repaint_func (mutter_repaint_func,
+  compositor->repaint_func_id = clutter_threads_add_repaint_func (meta_repaint_func,
                                                                   compositor,
                                                                   NULL);
 
   return compositor;
 }
 
+/**
+ * meta_get_overlay_window: (skip)
+ *
+ */
 Window
-mutter_get_overlay_window (MetaScreen *screen)
+meta_get_overlay_window (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
 
